@@ -19,7 +19,7 @@
 
 #include "grantleeeditor-version.h"
 #include "themeeditormainwindow.h"
-#include <qapplication.h>
+#include <QApplication>
 #include <kaboutdata.h>
 #include <KDBusService>
 #include <KLocalizedString>
